@@ -1,6 +1,6 @@
 ;;  -*-  indent-tabs-mode:nil; coding: utf-8 -*-
-;;  Copyright (C) 2022-2024
-;;      "Mu Lei" known as "NalaGinrut" <NalaGinrut@gmail.com>
+;;  Copyright (C) 2022-2025
+;;      "Mu Lei" known as "NalaGinrut" <mulei@gnu.org>
 ;;  Artanis is free software: you can redistribute it and/or modify
 ;;  it under the terms of the GNU General Public License and GNU
 ;;  Lesser General Public License published by the Free Software
@@ -18,7 +18,12 @@
 ;;  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (artanis client)
+  #:use-module (artanis utils)
+  #:use-module (artanis server server-context)
+  #:use-module (artanis runner)
+  #:use-module (artanis config)
   #:use-module (web response)
+  #:use-module (web http)
   #:use-module (web uri)
   #:use-module (srfi srfi-11)
   #:use-module (curl)
@@ -29,21 +34,34 @@
             artanis:http-delete
             artanis:http-put))
 
-;; It's recommend to use (artanis client) rather than (web client)
+;; It's recommended to use (artanis client) rather than (web client)
+
+(define (gen-headers-list headers)
+  (map (lambda (e)
+         (string-trim-both
+          (call-with-output-string
+           (lambda (port)
+             (write-header (car e) (cdr e) port)))))
+       headers))
 
 (define (request-it url handle headers cert bv?)
   (curl-easy-setopt handle 'url url)
   (curl-easy-setopt handle 'http-version 2)
-  (when (not cert)
+  (curl-easy-setopt handle 'followlocation #t)
+  (cond
+   ((not cert)
     (curl-easy-setopt handle 'ssl-verifypeer #f)
     (curl-easy-setopt handle 'ssl-verifyhost #f))
+   (else
+    (curl-easy-setopt handle 'sslcert cert)))
   (curl-easy-setopt handle 'httpheader
-                    (map (lambda (e)
-                           (format #f "~a: ~a"
-                                   (string-capitalize (symbol->string (car e)))
-                                   (cdr e)))
-                         headers))
-  (let* ((ret (curl-easy-perform handle bv? #t))
+                    (gen-headers-list headers))
+  (let* ((ret (call-with-runner
+               (lambda ()
+                 (DEBUG "artanis-client: do the request...~%")
+                 (let ((ret (curl-easy-perform handle bv? #t)))
+                   (DEBUG "artanis-client: done the request.~%")
+                   ret))))
          (code (curl-error-code))
          (errstr (curl-error-string)))
     (values ret code errstr)))
@@ -55,14 +73,18 @@
       (throw 'artanis-error 500 get-result
              (format #f "client error: method `~a', code `~a', errstr `~a'!"
                      method code errstr)))
-    (let* ((res (call-with-input-string (car ret) read-response))
+    (let* ((res (call-with-input-string
+                 (car ret)
+                 (lambda (port)
+                   ;; This loop make sure to get final result if there's
+                   ;; follow location like 301 or 302
+                   (let lp ((ret (read-response port)))
+                     (cond
+                      ((eof-object? (peek-char port)) ret)
+                      (else (lp (read-response port))))))))
            (body (cadr ret))
            (status (response-code res)))
       (cond
-       ((or (= status 301) (= status 302))
-        (let ((new-url (uri->string (assoc-ref (response-headers res)
-                                               'location))))
-          (get-result new-url method handle headers cert bv?)))
        ((not (zero? code))
         (curl-easy-cleanup handle)
         (throw 'artanis-error 500 get-result
