@@ -1,6 +1,6 @@
 ;;  -*-  indent-tabs-mode:nil; coding: utf-8 -*-
 ;;  Copyright (C) 2015
-;;      "Mu Lei" known as "NalaGinrut" <NalaGinrut@gmail.com>
+;;      "Mu Lei" known as "NalaGinrut" <mulei@gnu.org>
 ;;  Artanis is free software: you can redistribute it and/or modify
 ;;  it under the terms of the GNU General Public License and GNU
 ;;  Lesser General Public License published by the Free Software
@@ -22,21 +22,7 @@
   #:use-module (ice-9 command-line)
   #:export (show-version))
 
-(define copyright-year "2013~2015")
-(define author-str "NalaGinrut <mulei@gnu.org>\n")
-
-(define version-str
-  (string-append
-   (with-output-to-string
-    (lambda ()
-      (version-etc "GNU Artanis is a lightweight web framework written in Scheme.\n" ""
-		   #:copyright-holder "Mu Lei known as NalaGinrut" #:license "GPLv3+ & LGPLv3+" #:copyright-year copyright-year)))
-;;   (show-commands)
-   author-str
-   "Version: " artanis-version ".\n"
-   "God bless hacking.\n\n")) 
-
-(define (show-version) (display version-str))
+(define (show-version) (display artanis-version) (newline))
 
 (define %summary "Show the version info")
 (define main show-version)
