@@ -60,6 +60,7 @@
              page-options
              page-delete
 
+             plugin-enable!
              :sql-mapping
              :str
              :conn
@@ -439,6 +440,9 @@
         (((or 'ref 'get) key) (lpc-ref lpc key))
         ('(impl) (lpc-impl lpc))
         (else (throw 'artanis-err 500 gen-lpc-handler "Invalid cmd `~a'!" cmd)))))
+  (when (not (get-conf '(db lpc)))
+    (throw 'artanis-err 500 lpc-maker
+           "LPC is not enabled! Please set `(db lpc)' in your config file."))
   (match mode
     (#t
      (lambda (rc . cmd)
@@ -446,7 +450,7 @@
          (let ((lpc (or (get-lpc-instance!) ((new-lpc)))))
            (rc-lpc! rc lpc)))
        (gen-lpc-handler rc cmd)))
-    ((backend . args)
+    (('backend backend . args)
      (lambda (rc . cmd)
        (when (not (rc-lpc rc))
          (let ((lpc (or (get-lpc-instance!)
@@ -466,6 +470,11 @@
             (throw 'artanis-err 500 with-auth-maker
                    "PATH: ~a, ~a is not a thunk!" (rc-path rc) thunk))
         (failed-handler failed-url)))
+  (define (get-authn-token headers name)
+    ;; get from http header, Authentication: name token
+    (match (assoc-ref headers 'authorization)
+      (((? is-field?) key) key)
+      (else #f)))
   (lambda (rc failed-handler thunk)
     (match mode
       (#t
@@ -476,6 +485,14 @@
        (auth-action rc thunk failed-handler 'status))
       ((? procedure? generator)
        (auth-action rc thunk failed-handler generator))
+      (`(token ,name ,checker)
+       (let ((headers (rc-headers rc))
+             (token (get-authn-token headers name)))
+         (if (and token
+                  (or (not checker)
+                      (checker token)))
+             (thunk)
+             (failed-handler "/login"))))
       (else (throw 'artanis-err 500 with-auth-maker
                    "Invalid mode `~a'~" mode)))))
 
@@ -618,6 +635,8 @@
         (make-i18n-handler))))
   (lambda (rc)
     (match val
+      (('set lang) (parameterize ((current-lang lang))
+                     (make-i18n-handler)))
       ((? string? field) (from-url rc field))
       (`(cookie ,name) (from-cookie rc name))
       ('header (from-header rc))
@@ -819,6 +838,26 @@
   `(define-syntax-rule (,(symbol-append ': what) ?rc args ...)
      (=> ,(symbol->keyword what) ?rc args ...)))
 
+(define-syntax-rule (plugin-enable! name handler init ...)
+  (begin
+    (define-syntax-rule (call-plugin-init p)
+      (when (not (null? p)) ((car p))))
+    (call-plugin-init (list init ...))
+    (oh-set! (symbol->keyword 'name) handler)
+    (module-define! (resolve-module '(conf plugins))
+                    (symbol-append ': 'name)
+                    (lambda (rc . args)
+                      (let* ((opt (symbol->keyword 'name))
+                             (oht (rc-oht rc))
+                             (h (and oht (hash-ref oht opt))))
+                        (cond
+                         (h (apply h rc args))
+                         (else
+                          (throw 'artanis-err 500 'plugin-enable!
+                                 "BUG: ~a wasn't initialized!" opt))))))
+    (module-export! (resolve-module '(conf plugins))
+                    (list (symbol-append ': 'name)))))
+
 ;; register all the meta handler
 (meta-handler-register sql-mapping)
 (meta-handler-register str)
@@ -832,8 +871,6 @@
 (meta-handler-register from-post)
 (meta-handler-register websocket)
 (meta-handler-register lpc)
-
-;; No rc
 (meta-handler-register i18n)
 
 (define-syntax-rule (:cookies-set! rc ck k v)
@@ -886,6 +923,7 @@
                 ;; #:session requires #:cookies
                 (when (not (hash-ref oht #:cookies))
                   (init-oht! oht #:cookies #t rule keys))))
+              ;; init the handler
               (hash-set! oht k (h v rule keys)))
              (else #f))))
         opts)
