@@ -1,6 +1,6 @@
 ;;  -*-  indent-tabs-mode:nil; coding: utf-8 -*-
-;;  Copyright (C) 2014,2015,2017
-;;      "Mu Lei" known as "NalaGinrut" <NalaGinrut@gmail.com>
+;;  Copyright (C) 2014-2024
+;;      "Mu Lei" known as "NalaGinrut" <mulei@gnu.org>
 ;;  Artanis is free software: you can redistribute it and/or modify
 ;;  it under the terms of the GNU General Public License and GNU
 ;;  Lesser General Public License published by the Free Software
@@ -24,9 +24,10 @@
 ;;; Code:
 
 (define-module (artanis third-party json)
+  #:use-module (artanis utils)
   #:use-module (artanis env)
-  #:use-module (artanis third-party json upstream builder)
-  #:use-module (artanis third-party json upstream parser)
+  #:use-module (json builder)
+  #:use-module (json parser)
   #:use-module (artanis irregex)
   #:use-module (srfi srfi-1)
   #:export (->json-string
@@ -35,9 +36,7 @@
   #:re-export (scm->json
                scm->json-string
                json->scm
-               json-string->scm
-               json-parser?
-               json-parser-port))
+               json-string->scm))
 
 (define *word-re* (string->irregex "^[a-zA-Z0-9_]+$"))
 
@@ -75,15 +74,8 @@
                "Invalid JSONP, possibly be an XSS attack!" jsonp)))
    (else ((if securty-check? validate-json identity) (scm->json-string sxml)))))
 
-(define (json-ref json-obj key)
-  (let ((val (hash-ref json-obj key)))
-    (if (string? val)
-        ((current-encoder) val)
-        val)))
+(define (json-ref json-scm pattern)
+  (sxml-query pattern json-scm))
 
-(define (json-set! json-obj key val)
-  (hash-set! json-obj
-             ((current-encoder) key)
-             (if (string? val)
-                 ((current-encoder) val)
-                 val)))
+(define (json-set! json-scm key val)
+  (sxml-replace! json-scm key val))
